Python Agent Framework for Artificial Intelligence
===================================================

pyafai is an agent framework created for the Introduction to Artificial
Intelligence course at the Department of Informatics Engineering of the
University of Coimbra.

Tutorials and documentation are currently in preparation, and should be released
soon. In the meantime, the examples directory contains some simple examples of
the use of pyafai.

| Copyright (c) 2014-2016 Tiago Baptista - baptista@dei.uc.pt
| Licensed under the Apache License, Version 2.0 (see LICENSE.txt)


Dependencies
------------
- Python 3 (http://www.python.org) (should also work on Python 2.7)
- pyglet (http://www.pyglet.org)

Authors
-------
| Tiago Baptista

Other Contributors
------------------
| Ernesto Costa
| Alexandre Pinto
